import TinyH264Decoder from './TinyH264Decoder';
import TinyH264 from './TinyH264';
import tinyH264WasmURL from './TinyH264.wasm.asset';
var assets = {
  'TinyH264.wasm': tinyH264WasmURL
};
var h264Decoders = {};
/**
 * @param {*}module
 */

function loadNativeModule(module) {
  return new Promise(function (resolve) {
    if (module.calledRun) {
      resolve();
    } else {
      module.onRuntimeInitialized = function () {
        return resolve();
      };
    }
  });
}

function init() {
  var tinyH264 = TinyH264({
    locateFile: function locateFile(path) {
      return assets[path];
    }
  });
  return loadNativeModule(tinyH264).then(function () {
    self.addEventListener('message', function (e) {
      var message = e.data;
      var renderStateId = message.renderStateId;
      var messageType = message.type;

      switch (messageType) {
        case 'decode':
          {
            var decoder = h264Decoders[renderStateId];

            if (!decoder) {
              decoder = new TinyH264Decoder(tinyH264, function (output, width, height) {
                postMessage({
                  type: 'pictureReady',
                  width: width,
                  height: height,
                  renderStateId: renderStateId,
                  data: output.buffer
                }, [output.buffer]);
              });
              h264Decoders[renderStateId] = decoder;
            }

            decoder.decode(new Uint8Array(message.data, message.offset, message.length));
            break;
          }

        case 'release':
          {
            var _decoder = h264Decoders[renderStateId];

            if (_decoder) {
              _decoder.release();

              delete h264Decoders[renderStateId];
            }

            break;
          }
      }
    });
    self.postMessage({
      'type': 'decoderReady'
    });
  });
}

export { init };